@@ -271,6 +271,16 @@ class Log(object):
             )
         )
 
+    def stop_active_tasks(self, log_dt: datetime):
+        """Stop all active tasks by commiting changes to the logfile."""
+        query_date = log_dt.date()
+        task_mask = self._log_df[wc.COL_CATEGORY] == wc.TOKEN_TASK
+        date_mask = self._log_df["date"] == query_date
+        mask = task_mask & date_mask
+        active_task_ids = get_active_task_ids(self._log_df[mask])
+        for task_id in active_task_ids:
+            self._commit(wc.TOKEN_TASK, wc.TOKEN_STOP, log_dt, identifier=task_id)
+
     def task_report(self, task_id):
         """Generate a report of a given task."""
         task_mask = self._log_df[wc.COL_CATEGORY] == wc.TOKEN_TASK
